Entry

Struct Entry 

pub struct Entry { /* private fields */ }
An entry (row) in a JMap container

Implementations

Source

impl Entry

pub fn get_by_hash(&self, hash: u32) -> Option<&FieldValue>

Get a value by hash

pub fn get<H: HashTable>( &self, hash_table: &H, name: &str, ) -> Option<&FieldValue>

Get a value by name, using the provided hash table

pub fn get_int_by_hash(&self, hash: u32) -> Option<i32>

Get an integer value by hash

pub fn get_int<H: HashTable>(&self, hash_table: &H, name: &str) -> Option<i32>

Get an integer value by name

pub fn get_float_by_hash(&self, hash: u32) -> Option<f32>

Get a float value by hash

pub fn get_float<H: HashTable>(&self, hash_table: &H, name: &str) -> Option<f32>

Get a float value by name

pub fn get_string_by_hash(&self, hash: u32) -> Option<&str>

Get a string value by hash

pub fn get_string<H: HashTable>( &self, hash_table: &H, name: &str, ) -> Option<&str>

Get a string value by name

pub fn set_by_hash(&mut self, hash: u32, value: FieldValue)

Set a value by hash

pub fn set<H: HashTable>( &mut self, hash_table: &H, name: &str, value: FieldValue, )

Set a value by name, using the provided hash table

pub fn contains_hash(&self, hash: u32) -> bool

Check if this entry contains a field by hash

pub fn contains<H: HashTable>(&self, hash_table: &H, name: &str) -> bool

Check if this entry contains a field by name

pub fn len(&self) -> usize

Get the number of fields in this entry

pub fn is_empty(&self) -> bool

Check if this entry is empty

pub fn iter(&self) -> impl Iterator<Item = (&u32, &FieldValue)>

Iterate over all hash-value pairs