pub enum FieldValue {
Int(i32),
Float(f32),
String(String),
}Expand description
A value that can be stored in a JMap field
Variants
Int(i32)
Integer value (for Long, UnsignedLong, Short, Char)
Float(f32)
Floating point value
String(String)
String value (for String or StringOffset)
Implementations
Sourceimpl FieldValue
impl FieldValue
Sourcepub fn default_for(field_type: FieldType) -> Self
pub fn default_for(field_type: FieldType) -> Self
Get the default value for a field type
Sourcepub fn is_compatible_with(&self, field_type: FieldType) -> bool
pub fn is_compatible_with(&self, field_type: FieldType) -> bool
Check if this value is compatible with a field type