Structs
- File
Hash Table - A hash lookup table backed by a file of known field names
Enums
- Hash
Algorithm - Type of hash algorithm to use
Traits
- Hash
Table - Trait for hash table implementations
Functions
- calc_
hash - The hash function used by Super Mario Galaxy 1
- smg_
hash_ table - Create a hash table configured for Super Mario Galaxy 1/2
- smg_
hash_ table_ with_ lookup - Create a hash table for Super Mario Galaxy with a custom lookup file