Module io

Module io 

Structs

IoOptions
Options for reading/writing BCSV files

Enums

Encoding
String encoding options

Functions

from_buffer
Read a JMapInfo from a byte buffer
from_file
Read a JMapInfo from a file
to_buffer
Write a JMapInfo to a byte buffer This function serializes the JMapInfo into the BCSV format, including the header, field definitions, entries, and string table
to_file
Write a JMapInfo to a file