from_buffer

Function from_buffer 

pub fn from_buffer<H: HashTable>(
    hash_table: H,
    data: &[u8],
    options: &IoOptions,
) -> Result<JMapInfo<H>>
Read a JMapInfo from a byte buffer

Arguments

  • hash_table - The hash table to use for field name lookups
  • data - The byte buffer containing the BCSV data
  • options - Options for endianness and string encoding

TYpe

  • H - The type of hash table to use, which must implement the HashTable trait

Returns

A JMapInfo instance populated with the data from the buffer, or an error if parsing fails