pub struct Entry { /* private fields */ }Expand description
An entry (row) in a JMap container
Implementations
Sourceimpl Entry
impl Entry
Sourcepub fn get_by_hash(&self, hash: u32) -> Option<&FieldValue>
pub fn get_by_hash(&self, hash: u32) -> Option<&FieldValue>
Get a value by hash
Sourcepub fn get<H: HashTable>(
&self,
hash_table: &H,
name: &str,
) -> Option<&FieldValue>
pub fn get<H: HashTable>( &self, hash_table: &H, name: &str, ) -> Option<&FieldValue>
Get a value by name, using the provided hash table
Sourcepub fn get_int_by_hash(&self, hash: u32) -> Option<i32>
pub fn get_int_by_hash(&self, hash: u32) -> Option<i32>
Get an integer value by hash
Sourcepub fn get_int<H: HashTable>(&self, hash_table: &H, name: &str) -> Option<i32>
pub fn get_int<H: HashTable>(&self, hash_table: &H, name: &str) -> Option<i32>
Get an integer value by name
Sourcepub fn get_float_by_hash(&self, hash: u32) -> Option<f32>
pub fn get_float_by_hash(&self, hash: u32) -> Option<f32>
Get a float value by hash
Sourcepub fn get_float<H: HashTable>(&self, hash_table: &H, name: &str) -> Option<f32>
pub fn get_float<H: HashTable>(&self, hash_table: &H, name: &str) -> Option<f32>
Get a float value by name
Sourcepub fn get_string_by_hash(&self, hash: u32) -> Option<&str>
pub fn get_string_by_hash(&self, hash: u32) -> Option<&str>
Get a string value by hash
Sourcepub fn get_string<H: HashTable>(
&self,
hash_table: &H,
name: &str,
) -> Option<&str>
pub fn get_string<H: HashTable>( &self, hash_table: &H, name: &str, ) -> Option<&str>
Get a string value by name
Sourcepub fn set_by_hash(&mut self, hash: u32, value: FieldValue)
pub fn set_by_hash(&mut self, hash: u32, value: FieldValue)
Set a value by hash
Sourcepub fn set<H: HashTable>(
&mut self,
hash_table: &H,
name: &str,
value: FieldValue,
)
pub fn set<H: HashTable>( &mut self, hash_table: &H, name: &str, value: FieldValue, )
Set a value by name, using the provided hash table
Sourcepub fn contains_hash(&self, hash: u32) -> bool
pub fn contains_hash(&self, hash: u32) -> bool
Check if this entry contains a field by hash
Sourcepub fn contains<H: HashTable>(&self, hash_table: &H, name: &str) -> bool
pub fn contains<H: HashTable>(&self, hash_table: &H, name: &str) -> bool
Check if this entry contains a field by name
Sourcepub fn iter(&self) -> impl Iterator<Item = (&u32, &FieldValue)>
pub fn iter(&self) -> impl Iterator<Item = (&u32, &FieldValue)>
Iterate over all hash-value pairs