pub struct FileHashTable { /* private fields */ }Expand description
A hash lookup table backed by a file of known field names
Implementations
Sourceimpl FileHashTable
impl FileHashTable
Sourcepub fn new(algorithm: HashAlgorithm) -> Self
pub fn new(algorithm: HashAlgorithm) -> Self
Sourcepub fn from_file<P: AsRef<Path>>(
algorithm: HashAlgorithm,
path: P,
) -> Result<Self>
pub fn from_file<P: AsRef<Path>>( algorithm: HashAlgorithm, path: P, ) -> Result<Self>
Create a new hash table with the given algorithm and lookup file
The lookup file should contain one field name per line Lines starting with ‘#’ are treated as comments
Arguments
algorithm- The hash algorithm to use for calculating hashespath- The path to the lookup file containing field names
Types
P- A type that can be converted to aPathreference, such as&strorString
Errors
- If the file cannot be opened, a
JMapError::LookupFileNotFounderror is returned with the file path
Returns
A Result containing the new FileHashTable instance if successful, or a JMapError if the file cannot be read
Sourcepub fn algorithm(&self) -> HashAlgorithm
pub fn algorithm(&self) -> HashAlgorithm
Get the hash algorithm used by this table
Returns
The HashAlgorithm instance representing the hash algorithm used by this FileHashTable